dhcpkit.tests.ipv6.options.test_user_class_option module
========================================================

.. automodule:: dhcpkit.tests.ipv6.options.test_user_class_option
    :members:
    :undoc-members:
    :show-inheritance:
